public inbox for gdb-cvs@sourceware.org
help / color / mirror / Atom feed
* [binutils-gdb] Change the key type in psym_index_map
@ 2022-04-12 15:41 Tom Tromey
  0 siblings, 0 replies; only message in thread
From: Tom Tromey @ 2022-04-12 15:41 UTC (permalink / raw)
  To: gdb-cvs

https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=88a981942d16cbf4a75581aa72744e8d778bcd38

commit 88a981942d16cbf4a75581aa72744e8d778bcd38
Author: Tom Tromey <tom@tromey.com>
Date:   Thu May 27 14:59:32 2021 -0600

    Change the key type in psym_index_map
    
    In order to change the DWARF index writer to avoid partial symtabs,
    this patch changes the key type in psym_index_map (and renames that
    type as well).  Using the dwarf2_per_cu_data as the key makes it
    simpler to reuse this code with the new indexer.

Diff:
---
 gdb/dwarf2/index-write.c | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/gdb/dwarf2/index-write.c b/gdb/dwarf2/index-write.c
index 95202db2810..958fc9bed3b 100644
--- a/gdb/dwarf2/index-write.c
+++ b/gdb/dwarf2/index-write.c
@@ -407,17 +407,17 @@ write_hash_table (mapped_symtab *symtab, data_buf &output, data_buf &cpool)
     }
 }
 
-typedef std::unordered_map<partial_symtab *, unsigned int> psym_index_map;
+typedef std::unordered_map<dwarf2_per_cu_data *, unsigned int> cu_index_map;
 
 /* Helper struct for building the address table.  */
 struct addrmap_index_data
 {
-  addrmap_index_data (data_buf &addr_vec_, psym_index_map &cu_index_htab_)
+  addrmap_index_data (data_buf &addr_vec_, cu_index_map &cu_index_htab_)
     : addr_vec (addr_vec_), cu_index_htab (cu_index_htab_)
   {}
 
   data_buf &addr_vec;
-  psym_index_map &cu_index_htab;
+  cu_index_map &cu_index_htab;
 
   int operator() (CORE_ADDR start_addr, void *obj);
 
@@ -447,7 +447,7 @@ add_address_entry (data_buf &addr_vec,
 int
 addrmap_index_data::operator() (CORE_ADDR start_addr, void *obj)
 {
-  partial_symtab *pst = (partial_symtab *) obj;
+  dwarf2_psymtab *pst = (dwarf2_psymtab *) obj;
 
   if (previous_valid)
     add_address_entry (addr_vec,
@@ -457,7 +457,7 @@ addrmap_index_data::operator() (CORE_ADDR start_addr, void *obj)
   previous_cu_start = start_addr;
   if (pst != NULL)
     {
-      const auto it = cu_index_htab.find (pst);
+      const auto it = cu_index_htab.find (pst->per_cu_data);
       gdb_assert (it != cu_index_htab.cend ());
       previous_cu_index = it->second;
       previous_valid = true;
@@ -474,7 +474,7 @@ addrmap_index_data::operator() (CORE_ADDR start_addr, void *obj)
 
 static void
 write_address_map (dwarf2_per_bfd *per_bfd, data_buf &addr_vec,
-		   psym_index_map &cu_index_htab)
+		   cu_index_map &cu_index_htab)
 {
   struct addrmap_index_data addrmap_index_data (addr_vec, cu_index_htab);
 
@@ -1317,11 +1317,11 @@ write_gdbindex (dwarf2_per_objfile *per_objfile, FILE *out_file,
   data_buf objfile_cu_list;
   data_buf dwz_cu_list;
 
   /* While we're scanning CU's create a table that maps a psymtab pointer
      (which is what addrmap records) to its index (which is what is recorded
      in the index file).  This will later be needed to write the address
      table.  */
-  psym_index_map cu_index_htab;
+  cu_index_map cu_index_htab;
   cu_index_htab.reserve (per_objfile->per_bfd->all_comp_units.size ());
 
   /* Store out the .debug_type CUs, if any.  */
@@ -1349,7 +1349,7 @@ write_gdbindex (dwarf2_per_objfile *per_objfile, FILE *out_file,
 	    recursively_write_psymbols (objfile, psymtab, &symtab,
 					psyms_seen, this_counter);
 
-	  const auto insertpair = cu_index_htab.emplace (psymtab,
+	  const auto insertpair = cu_index_htab.emplace (per_cu,
 							 this_counter);
 	  gdb_assert (insertpair.second);
 	}


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-04-12 15:41 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -1317,11 +1317,11 @@ write_gdbindex (dwarf2_per_objfile *per_objfile, FILE *out_file,
   data_buf dwz_cu_list;
 
-  /* While we're scanning CU's create a table that maps a psymtab pointer
+  /* While we're scanning CU's create a table that maps a dwarf2_per_cu_data
      (which is what addrmap records) to its index (which is what is recorded
      in the index file).  This will later be needed to write the address
2022-04-12 15:41 [binutils-gdb] Change the key type in psym_index_map Tom Tromey

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).